@@ -19,11 +19,11 @@ LAUNCH_CONDITION__WINDOWS_2008_AND_R2_ONLY = \
     "(Not VersionNT=502) And (Not (VersionNT=600 And (MsiNTProductType=1))) And " + \
     "(Not (VersionNT=601 And (MsiNTProductType=1)))"
 OS_REQUIREMENTS_LAUNCH_CONDITION_MESSAGE = "The operating system is not adequate for running [ProductName]."
-
+OS_32BIT_ON_64BIT_LAUNCH_CONDITION_MESSAGE = "[ProductName] installation on a 64-bit operating system requires the 64-bit installation package. Please get the 64-bit package and try again."
 OPERATING_SYSTEMS = {
                      # OS Name: (allow-install, condition)
-                     "Windows Server 2012": (True, '(VersionNT=602 And (MsiNTProductType=2 Or MsiNTProductType=3)'),
-                     "Windows 8": (False, '(VersionNT=602 And (MsiNTProductType=1)'),
+                     "Windows Server 2012": (True, '(VersionNT=602 And (MsiNTProductType=2 Or MsiNTProductType=3))'),
+                     "Windows 8": (False, '(VersionNT=602 And (MsiNTProductType=1))'),
                      "Windows Server 2008 R2": (True,
                                                 '(VersionNT=601 And (MsiNTProductType=2 Or MsiNTProductType=3))'),
                      "Windows Server 2008": (True,
@@ -41,6 +41,7 @@ SILENT_LAUNCHER = "silent_launcher-{}.exe"
 
 class Recipe(PackagingRecipe):
     def install(self):
+        self.delete_non_production_packages_from_cache_dist()
         self.signtool = self.get_signtool()
         self.write_buildout_configuration_file_for_production()
         utils.download_buildout(self.get_download_cache_dist())
@@ -113,7 +114,8 @@ class Recipe(PackagingRecipe):
         self._add_project_entry_points(wix, silent_launcher_file_id)
         arp_icon = self.get_add_remove_programs_icon()
         if arp_icon:
-            wix.set_add_remove_programs_icon(arp_icon)
+            arp_icon = wix.set_add_remove_programs_icon(arp_icon)
+        self._add_shortcuts(wix)
         banner_bmp = self.get_msi_banner_bmp()
         if banner_bmp:
             logger.info("Setting custom banner {}".format(banner_bmp))
@@ -122,7 +124,6 @@ class Recipe(PackagingRecipe):
         if dialog_bmp:
             logger.info("Setting custom dialog {}".format(dialog_bmp))
             wix.new_element("WixVariable", {"Id": "WixUIDialogBmp", "Value": dialog_bmp}, wix.product)
-        wix.set_allusers()
         return wix
 
     @contextmanager
@@ -139,8 +140,7 @@ class Recipe(PackagingRecipe):
         from os import close
         fd, path = mkstemp(suffix='.zip')
         close(fd)
-        urlretrieve("http://download-codeplex.sec.s-msft.com/Download/Release?ProjectName=wix&DownloadId=204418&FileTime=129409234233530000&Build=19331",
-                    path)
+        urlretrieve("ftp://python.infinidat.com/archives/wix-binaries-v3.5-windows-x86.zip", path)
         return path
 
     def _append_bindir_to_system_path(self, wix):
@@ -148,7 +148,7 @@ class Recipe(PackagingRecipe):
         bindir = wix.mkdir('bin', wix.installdir)
         assembly_dir = wix.mkdir('Microsoft.VC90.CRT', bindir)
         component = wix.new_component(wix.new_id('bin'), bindir, generate_guid())
-        wix.add_environment_variable('Path', r'[INSTALLDIR]\bin', component)
+        wix.add_environment_variable('Path', r'[INSTALLDIR]bin', component)
         wix.add_delete_all_files_on_removal_component_to_directory(bindir)
         wix.add_delete_empty_folder_component_to_directory(bindir)
 
@@ -179,7 +179,7 @@ class Recipe(PackagingRecipe):
 
     def _append_bootstrap_custom_action(self, wix, os_removedirs_eggs_id, silent_launcher_file_id):
         commandline = r'"[INSTALLDIR]parts\python\bin\python.exe" bootstrap.py ' + \
-                      r'--download-base=.cache\dist --setup-source=.cache\dist\distribute_setup.py'
+                      r'--download-base=.cache\dist --setup-source=.cache\dist\distribute_setup.py --version=1.6.3'
         action = wix.add_deferred_in_system_context_custom_action('bootstrap', commandline,
                                                                   after=os_removedirs_eggs_id,
                                                                   condition=CONDITION_DURING_INSTALL_OR_REPAIR,
@@ -200,6 +200,16 @@ class Recipe(PackagingRecipe):
 
     def _add_launch_conditions(self, wix):
         self._add_os_requirements_launch_condition(wix)
+        self._prevent_32bit_installations_on_64bit_os(wix)
+
+    def _prevent_32bit_installations_on_64bit_os(self, wix):
+        from sys import maxsize
+        is_64 = maxsize > 2 ** 32
+        if is_64:
+            return
+        condition = wix.new_element("Condition", {'Message': OS_32BIT_ON_64BIT_LAUNCH_CONDITION_MESSAGE},
+                                    wix.product)
+        condition.text = "Not VersionNT64"
 
     def _add_os_requirements_launch_condition(self, wix):
         condition = wix.new_element("Condition", {'Message': OS_REQUIREMENTS_LAUNCH_CONDITION_MESSAGE},
@@ -237,10 +247,15 @@ class Recipe(PackagingRecipe):
                                                              condition=value['condition'],
                                                              silent_launcher_file_id=silent_launcher_file_id)
 
+    def _add_shortcuts(self, wix):
+        if not self.get_startmenu_shortcuts() or not self.get_shortcuts_icon():
+            return
+        icon_id = wix.new_icon(self.get_shortcuts_icon())
+        for item in eval(self.get_startmenu_shortcuts()):
+            shortcut_name, executable_name = item.split('=')
+            wix.add_shortcut(shortcut_name.strip(), executable_name.strip(), icon_id)
+
     def get_msi_filepath(self):
         return path.join(self.get_working_directory(), "{}-{}-{}.msi".format(self.get_package_name(),
                                                                       self.get_project_version__long(),
                                                                       self.get_os_string()))
-
-
-
